/**
 * \file 
 * \brief Implementation of the CpFit program main window
 * and data files loader/saver
 *
 * \author Alexey L. Voskov (alvoskov@gmail.com)
 * \copyright (C) 2016-2017 Alexey L. Voskov
 *
 * Laboratory of Chemical Thermodynamics, Department of Chemistry,
 *
 * Lomonosov Moscow State University, Moscow, Russia, 119991
 *
 * This file is the part of the CpFit program
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/);
 */

 
#ifndef __HELLO_H
#define __HELLO_H

#include "customgrids.h"


/**
 * \brief  Main window of the CpFit program
 *
 * The window essentially shows two things: content of a file/data set and
 * initial approximation for the model parameters. It is possible to edit
 * all data and metainformation, input arbitrary alpha/theta initial approximations,
 * manage the optimization process and load/save data files.
 */
class MainWindow : public wxFrame
{
public:
	MainWindow();
	std::vector <double> ReadAlpha();
	std::vector <double> ReadTheta();
	bool WriteAlpha(std::vector <double> alpha);
	bool WriteTheta(std::vector <double> theta);
	bool WriteExtraTermsParams(std::vector <ExtraTerm> &extraTerms_new);	
private:
	// Grids (with parameters and data)
	wxGrid *grPar;
  	DataFileEditor *ctlData;
	// Frames and notebooks
	wxStaticBox *box, *boxData, *boxInfo;
	// Buttons
	wxButton *btnCalc, *btnReset;
	// Another controls
	wxComboBox *cmbParNum;
	wxString strNotNumeric;
	wxTextCtrl *txtFileInfo[3];
	wxStaticText *lblFileInfo[3];
	wxStaticText *lblParNum;
	// Event handlers
	void OnSize(wxSizeEvent &event);
	void OnNew(wxCommandEvent &event);
	void OnOpenFile(wxCommandEvent &event);
	void OnSaveAsFile(wxCommandEvent &event);
	void OnLoadParameters(wxCommandEvent &event);
	void OnAbout(wxCommandEvent &event);

	void OnResetPar(wxCommandEvent &event);
	void OnEvalPar(wxCommandEvent &event);
	void OnAutoEvalPar(wxCommandEvent &event);
	void OnAddTermsEvalPar(wxCommandEvent &event);
	void OnEvalExTermsOnly(wxCommandEvent &event);
	void OnNoOptEvalPar(wxCommandEvent &event);	

	void OnTextEvent(wxCommandEvent& event);
	
	void OnExit(wxCommandEvent &event);
	void OnClose(wxCloseEvent &event);
	void OnCmbParNum(wxCommandEvent &event);
	void OnParamGridCellChanging(wxGridEvent& event);
	wxDECLARE_EVENT_TABLE();
	// Our internal utilities
	XYDataFile dataFile;
	bool isFileChanged;
	void SetIsFileChanged(bool value);
	void ResizeParamGrid(int numOfRows);
	void RefreshDataGrid();
	void RefreshTitle();
	// Some strings
	wxString strInitApprox;
	wxString strInputData;
	wxString strNumOfTerms;
	wxString strResetParams;
	
};
#endif
