/**
 * \file 
 * \brief Debye function implemenation
 *
 * This file contains Debye function implementation and Cp(T) function for
 * Debye model of heat capacity. It is used to estimate uncertainty of
 * Einstein-Plank functions sum at low (He) temperatures.
 *
 * \author Alexey L. Voskov (alvoskov@gmail.com)
 * \copyright (C) 2017 Alexey L. Voskov
 *
 * Laboratory of Chemical Thermodynamics, Department of Chemistry,
 *
 * Lomonosov Moscow State University, Moscow, Russia, 119991
 *
 * This file is the part of the CpFit program
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/);
 */

#ifndef __DFUNC3_H
#define __DFUNC3_H
double debye_func_3(double x);
double c_debye_func(double x);
double S_debye_func(double Tnorm);
double int_adaptive_simpson(std::function <double(double)> f, double a, double b);
#endif



