#include <stdio.h>
#include <math.h>
#include <float.h>
#include <functional>
#include "dfunc3.h"

/** CODATA 2014 molar gas constant */
#define CONST_R 8.3144598


/* Function for numerical integration*/
double ddfunc3(double y)
{
	return (y >= DBL_EPSILON) ? (pow(y, 3) / (exp(y) - 1)) : (y*y);
}

/* Debye function (by means of numerical integration) */
double dfunc3_numint(double x)
{
	if (x >= DBL_EPSILON) {
		return 3.0/pow(x,3) * int_adaptive_simpson(ddfunc3, 0, x);
	} else {
		return 1 - 0.375*x;
	}
}

int main()
{
	double Tn[] = {1e-3, 1e-2, 0.1, 1, 10, 50, 1000, -1};
	printf("Functions values\n");
	printf("%10s %25s %25s\n", "T/TD=1/x", "DFUNC3", "C3RFUNC");
	for (double *Tni = Tn; *Tni != -1; Tni++) {
		double x = 1 / *Tni;
		printf("%10.3g %25.15g %25.15g\n", *Tni, debye_func_3(x), c_debye_func(x));
	}
	printf("\n");
	

	printf("Simpson adaptive integration test\n");
	printf("%10s %20s %20s %20s\n", "x", "SERIES", "SIMPSON", "C3RFUNC");
	for (double x = 0.0; x < 5.0; x += 0.5) {
		printf("%10.3g %20.15g %20.15g %20.15g\n", x, debye_func_3(x), dfunc3_numint(x), c_debye_func(x));
	}


	printf("Entropy function test\n");
	double TD = 516.707, T0 = 298.15; // K
	printf("%g\n", S_debye_func(T0/TD)*(4*3*CONST_R));

	
	return 0;
}
