/**
 * \file
 * \brief Implementation of thermodynamic tables, e.g. tables of tabulated
 * thermodynamic functions values, tables of residuals etc.
 * 
 * \author Alexey L. Voskov (alvoskov@gmail.com)
 * \copyright (C) 2016-2017 Alexey L. Voskov
 *
 * Laboratory of Chemical Thermodynamics, Department of Chemistry,
 *
 * Lomonosov Moscow State University, Moscow, Russia, 119991
 *
 * This file is the part of the CpFit program
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/);
 */

#ifndef __TDTABLE_H
#define __TDTABLE_H


/**
 * \brief Table with tabulated values of thermodynamic functions
 */
class TdTableWindow : public wxFrame
{
public:
	TdTableWindow(wxWindow *parent, LSQResult *res, const wxString &title);
private:
	bool useConfIntervals;
	std::vector <double> TVector;
	void RenderHeader();
	void RenderTVector();

	wxGrid *grData;
	LSQResult lsqRes;
	
	void OnSize(wxSizeEvent &event);
	void OnClose(wxCloseEvent &event);
	void OnResetTable(wxCommandEvent &event);
	void OnAddTableRange(wxCommandEvent &event);
	void OnSaveAs(wxCommandEvent &event);
	void OnSetErrMode(wxCommandEvent &event);	

	wxDECLARE_EVENT_TABLE();
};

/**
 * \brief Table with residuals for user data set (currently only for Cp).
 * Absolute and relative deviations are supported.
 */
class ResTableWindow : public wxFrame
{
public:
	ResTableWindow(wxWindow *parent, TDDataType dataType, LSQContext &lsqCont, LSQResult &lsqRes, const wxString &title);
private:
	LSQContext lsqCont;
	LSQResult lsqRes;
	TDDataType dataType;

	wxGrid *grData;

	void OnSize(wxSizeEvent &event);
	void OnSaveAs(wxCommandEvent &event);
	void OnClose(wxCloseEvent &event);

	wxDECLARE_EVENT_TABLE();	
};

#endif
